ThreeDeviceStatus class
Properties
-
gear
↔ int
-
档位 0-100
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isOn
↔ int
-
开关机状态 1.开机 2.关机
getter/setter pair
-
mode
↔ int
-
模式 1.捶打 2.按压 3.揉捏 4.推拿 5.自定义
getter/setter pair
-
power
↔ int
-
电量
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
type
↔ int
-
产品类型 0-10(0:未接外设)(1:衣服)(2:提臀短裤)2K(3:腰带)500欧姆(4:背心)5K (......预留)
getter/setter pair
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited